<?php
/*
Simple:Press
Topic Watches plugin database routines
$LastChangedDate: 2013-08-23 12:55:44 -0700 (Fri, 23 Aug 2013) $
$Rev: 10569 $
*/

if (preg_match('#'.basename(__FILE__).'#', $_SERVER['PHP_SELF'])) die('Access denied - you cannot directly call this file');

include_once(WLIBDIR.'sp-watches-components.php');

function sp_watches_add_watches($topicid, $users) {
    global $spThisUser;
	if (!$spThisUser->admin && !$spThisUser->moderator) return;
    if (empty($topicid) || empty($users)) return;

    foreach ($users as $user) {
        sp_watches_save_watch($topicid, $user, false);
    }

	sp_notify(0, __('Topic watch(es) added', 'sp-watches'));
}

function sp_watches_do_member_add($userid) {
	$sql = 'UPDATE '.SFMEMBERS.' SET watches = "" WHERE user_id='.$userid;
	spdb_query($sql);
}

function sp_watches_do_member_del($userid) {
	$watches = sp_get_member_item($userid, 'watches');
	if (!empty($watches)) {
		foreach ($watches as $watch) {
			sp_watches_remove_watch($watch, $userid);
		}
	}
}

function sp_watches_remove_watch($topic, $userid, $retmessage=true) {
	global $spThisUser;

	if (!$userid || !$topic) return '';
	if (!$spThisUser->admin && $spThisUser->ID != $userid) return;
	$forumid = spdb_table(SFTOPICS, "topic_id=$topic", 'forum_id');
	if (!sp_get_auth('watch', $forumid, $userid)) return;

	# remove current watch from member
	$list = sp_get_member_item($userid, 'watches');
	if (!empty($list)) {
		$newlist = '';
		foreach($list as $topicid) {
			if ($topic != $topicid) $newlist[] = $topicid;
		}
		sp_update_member_item($userid, 'watches', $newlist);
	}

	#remove the topic watch
	$list = spdb_table(SFTOPICS, "topic_id=$topic", 'topic_watches');
	if (!empty($list)) {
		$newlist = '';
		$list = unserialize($list);
		foreach ($list as $user) {
			if ($userid != $user) $newlist[] = $user;
		}
		if ($newlist != '') $newlist = serialize($newlist);
		$list = spdb_query('UPDATE '.SFTOPICS." SET topic_watches ='$newlist' WHERE topic_id=$topic");
	}

	if ($retmessage) sp_notify(0, __('Topic watch removed', 'sp-watches'));
}

function sp_watches_save_watch($topicid, $userid, $retmessage=true) {
	global $spVars;

	if (!$userid || !$topicid) return;
	if (!sp_get_auth('watch', $spVars['forumid'], $userid)) return;

	# is user already watching this topic?
	if (sp_watches_is_watching($userid, $topicid)) {
		if ($retmessage) sp_notify(1, __('You are already watching this topic', 'sp-watches'));
		return;
	}

	# OK - watch the topic (in members table)
	$list = sp_get_member_item($userid, 'watches');
	$list[] = $topicid;
	sp_update_member_item($userid, 'watches', $list);

	# OK - watch the topic
	$list = spdb_table(SFTOPICS, "topic_id=$topicid", 'topic_watches');
	$list = unserialize($list);
	$list[] = $userid;
	$list = serialize($list);
	spdb_query('UPDATE '.SFTOPICS." SET topic_watches = '$list' WHERE topic_id=$topicid");

	if ($retmessage) sp_notify(0, __('Topic watch added', 'sp-watches'));
}

function sp_watches_remove_user_watches($userid) {
	global $spThisUser;

	# make sure user is doing this
	if ($spThisUser->admin || $userid == $spThisUser->ID) {
		# Remove watches
		$watches = sp_get_member_item($userid, 'watches');
		if (!empty($watches)) {
			foreach ($watches as $watch) {
				sp_watches_remove_watch($watch, $userid);
			}
		}
	}
}

function sp_watches_get_topic_watches($filter, $groups, $forums, $curpage, $search) {
	# setup where we are in the list (paging)
	$startlimit = 0;
	if ($curpage != 1) $startlimit = ($curpage - 1) * 20;

	$limit = ' LIMIT '.$startlimit.', 20';

	$where2 = ' AND topic_watches != ""';

	# create the join based on all, group or forum filter
	if ($filter == 'groups' && $groups[0] != -1) {
		$where1 = ' WHERE '.SFGROUPS.".group_id IN (".implode(",", $groups).")";
	} elseif ($filter == 'forums' && $forums[0] != -1) {
		$where1 = ' WHERE '.SFFORUMS.".forum_id IN (".implode(",", $forums).")";
	} else { # all groups/forums
		$where1 = ' WHERE 1';
	}

	# any search terms?
	$like = '';
	if (!empty($search)) $like = ' AND topic_name LIKE "%'.esc_sql(like_escape($search)).'%"';

	# retrieve watched topic records
	$query = 'SELECT SQL_CALC_FOUND_ROWS topic_id, topic_name, topic_slug, group_name, forum_name, forum_slug, topic_watches
			 FROM '.SFTOPICS.'
			 JOIN '.SFFORUMS.' ON '.SFFORUMS.'.forum_id = '.SFTOPICS.'.forum_id
			 JOIN '.SFGROUPS.' ON '.SFGROUPS.'.group_id = '.SFFORUMS.'.group_id '.
			 $where1.$where2.$like.' ORDER BY topic_id DESC'.$limit;
	$records['data'] = spdb_select('set', $query);
	$records['count'] = spdb_select('var', 'SELECT FOUND_ROWS()');

	return $records;
}

function sp_watches_get_user_watches($curpage, $search) {
	# setup where we are in the list (paging)
	$startlimit = 0;
	if ($curpage != 1) $startlimit = ($curpage - 1) * 20;

	$limit = ' LIMIT '.$startlimit.', 20';

	$where = ' WHERE watches != ""';

	# any search terms?
	$like = '';
	if (!empty($search)) $like = ' AND display_name LIKE "%'.esc_sql(like_escape($search)).'%"';

	# retrieve watched topic records
	$query = 'SELECT SQL_CALC_FOUND_ROWS user_id, display_name, watches
			 FROM '.SFMEMBERS.
			 $where.$like.' ORDER BY user_id DESC'.$limit;
	$records['data'] = spdb_select('set', $query);
	$records['count'] = spdb_select('var', 'SELECT FOUND_ROWS()');

	return $records;
}

function sp_watches_remove_topic_watches($tid) {
	$list = spdb_table(SFTOPICS, "topic_id=$tid", 'topic_watches');
	$list = unserialize($list);
	for ($x=0; $x<count($list); $x++) {
		# remove watch from member
		$topics = sp_get_member_item($list[$x], 'watches');
		if (!empty($topics)) {
			$newlist = array();
			foreach ($topics as $topic) {
				if ($topic != $tid) $newlist[] = $topic;
			}
			sp_update_member_item($list[$x], 'watches', $newlist);
		}
	}
	$query = 'UPDATE '.SFTOPICS." SET topic_watches='' WHERE topic_id=$tid";
	spdb_select('var', $query);
}

?>